@@ -1,5 +1,9 @@
+__version__ = '1.1'
+
+
 from MRCpy.base_mrc import BaseMRC
 from MRCpy.cmrc import CMRC
 from MRCpy.mrc import MRC
+from MRCpy.amrc import AMRC
 
-__all__ = ['BaseMRC', 'MRC', 'CMRC']
+__all__ = ['BaseMRC', 'MRC', 'CMRC', 'AMRC']
