@@ -44,7 +44,7 @@ class MRC(BaseMRC):
 
     .. _ref1:
     .. seealso:: For more information about MRC, one can refer to the following
-    resources:
+        resources:
 
                     [1] `Mazuelas, S., Zanoni, A., & Pérez, A. (2020).
                     Minimax Classification with
@@ -726,7 +726,7 @@ class MRC(BaseMRC):
                 if f_k_next < f_star:
                     f_star = f_k_next
                     mu_star = mu_k_next
-                    v_star = v_k_next[i_k_next]
+                    v_star = -v_k_next[i_k_next]
 
                 # Update variables
                 mu_k = mu_k_next
@@ -767,7 +767,7 @@ class MRC(BaseMRC):
                 if f_k_next < f_star:
                     f_star = f_k_next
                     mu_star = mu_k_next
-                    v_star = v_k_next[i_k_next]
+                    v_star = -v_k_next[i_k_next]
 
                 # Update variables
                 mu_k = mu_k_next
@@ -785,7 +785,7 @@ class MRC(BaseMRC):
                        'w_k_prev': w_k.flatten(),
                        'mu': mu_star.flatten(),
                        'nu': v_star,
-                       'best_value': f_star,
+                       'best_value': f_star[0][0],
                        }
 
         return new_params_
@@ -829,11 +829,6 @@ class MRC(BaseMRC):
             c = np.tile(c, (self.n_classes, 1)).transpose()
             hy_x = hy_x / c
 
-            # Set the approach for prediction to non-deterministic
-            # if not provided by user.
-            if self.deterministic is None:
-                self.deterministic = False
-
         elif self.loss == 'log':
             # Constraints in case of log loss function
 
@@ -845,9 +840,4 @@ class MRC(BaseMRC):
                              for i in range(self.n_classes)).transpose()
             hy_x = np.reciprocal(hy_x)
 
-            # Set the approach for prediction to deterministic
-            # if not provided by user.
-            if self.deterministic is None:
-                self.deterministic = True
-
         return hy_x
